Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Options ¶
type Options struct {
Log *log.Options
SecureServing *apiserveroptions.SecureServingOptions
Debug *apiserveroptions.DebugOptions
ETCD *storageoptions.ETCDStorageOptions
Generic *apiserveroptions.GenericOptions
Authentication *apiserveroptions.AuthenticationWithAPIOptions
Authorization *apiserveroptions.AuthorizationOptions
PlatformAPIClient *controlleroptions.APIServerClientOptions
// The Registry will load its initial configuration from this file.
// The path may be absolute or relative; relative paths are under the Monitor's current working directory.
LogagentConfig string
Audit *genericapiserveroptions.AuditOptions
}
Options is the main context object for the TKE monitor.
func NewOptions ¶
NewOptions creates a new Options with a default config.
func (*Options) AddFlags ¶
AddFlags adds flags for a specific server to the specified FlagSet object.
func (*Options) ApplyFlags ¶
ApplyFlags parsing parameters from the command line or configuration file to the options instance.
Click to show internal directories.
Click to hide internal directories.