Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
SecureServing *apiserver.SecureServingInfo
// LoopbackClientConfig is a config for a privileged loopback connection
LoopbackClientConfig *restclient.Config
Authentication apiserver.AuthenticationInfo
Authorization apiserver.AuthorizationInfo
ServerName string
// the client only used for leader election
LeaderElectionClient *versionedclientset.Clientset
// the rest config for the notify apiserver
NotifyAPIServerClientConfig *restclient.Config
Component controlleroptions.ComponentConfiguration
}
Config is the running configuration structure of the TKE controller manager.
Click to show internal directories.
Click to hide internal directories.